@@ -11,6 +11,11 @@ highlightText <- function(
    style = "background-color:yellow; font-weight:bold;",
    class = "bed-search"
 ){
+   style <- paste(c(style, ";"), collapse = "; ")
+   style <- gsub(";[[:blank:]]*;", ";", style)
+   if(!grepl("padding", style)){
+      style <- paste(style, "padding:0;")
+   }
    value <- sub('^"', '', sub('"$', '', value))
    value <- gsub("[[:punct:]]", ".?", value)
    return(unlist(lapply(
@@ -61,10 +66,15 @@ highlightText <- function(
 #' BE are converted to genes.
 #' @param excludeTechID do not display BED technical BEIDs
 #' @param multiple allow multiple selections (default=FALSE)
-#' @param beOfInt if toGene==FALSE, BE to consider (default=NULL ==> all)
-#' @param selectBe if toGene==FALSE, display an interface for selecting BE
+#' @param beOfInt if toGene == FALSE, BE to consider (default=NULL ==> all)
+#' @param selectBe if toGene == FALSE, display an interface for selecting BE
 #' @param orgOfInt organism to consider (default=NULL ==> all)
 #' @param selectOrg display an interface for selecting organisms
+#' @param groupBySymbol if TRUE also use gene symbols to aggregate results with
+#' more granularity (taken into account only when toGene == TRUE)
+#' @param searchLabel display label for the search field or NULL for no label
+#' @param matchColname display name of the match column
+#' @param selectFirst if TRUE the first row is selected by default
 #' @param oneColumn if TRUE the hits are displayed in only one column
 #' @param withId if FALSE and one column, the BEIDs are not shown
 #' @param maxHits maximum number of raw hits to return
@@ -113,14 +123,21 @@ highlightText <- function(
 #'
 #' @importFrom shiny reactive renderUI observe fluidRow column textInput NS selectizeInput reactiveValues withProgress req
 #' @importFrom DT datatable DTOutput renderDT formatStyle styleEqual
+#' @importFrom htmltools tagQuery
+#' @importFrom stats setNames
 #' @export
 #'
 beidsServer <- function(
    id,
-   toGene=TRUE, excludeTechID=FALSE,
+   toGene=TRUE,
+   excludeTechID=FALSE,
    multiple=FALSE,
    beOfInt=NULL, selectBe=TRUE,
    orgOfInt=NULL, selectOrg=TRUE,
+   groupBySymbol = FALSE,
+   searchLabel = "Search a gene",
+   matchColname = "Match",
+   selectFirst = FALSE,
    oneColumn = FALSE,
    withId = FALSE,
    maxHits = 75,
@@ -156,12 +173,15 @@ beidsServer <- function(
             shiny::fluidRow(
                shiny::column(
                   cw,
-                  shiny::textInput(
-                     inputId=shiny::NS(id, "beSearchTerm"),
-                     label="Search a gene",
-                     placeholder='e.g. snca, ENSG00000186868, "M-CSF receptor"',
-                     width="100%"
-                  )
+                  htmltools::tagQuery(
+                     shiny::textInput(
+                        inputId=shiny::NS(id, "beSearchTerm"),
+                        label=searchLabel,
+                        placeholder=
+                           'e.g. snca, ENSG00000186868, "M-CSF receptor"',
+                        width="100%"
+                     )
+                  )$find("input")$addAttrs("autocomplete" = "off")$allTags()
                ),
                if(selectBe){
                   shiny::column(
@@ -282,7 +302,15 @@ beidsServer <- function(
                g <- dplyr::mutate(
                   g, url=getBeIdURL(.data$GeneID, .data$Gene_source)
                )
-               g <- dplyr::group_by(g, .data$Gene_entity, .data$organism)
+               if(groupBySymbol){
+                  g <- dplyr::group_by(
+                     g, .data$Gene_entity, .data$organism, .data$Gene_symbol
+                  )
+               }else{
+                  g <- dplyr::group_by(
+                     g, .data$Gene_entity, .data$organism
+                  )
+               }
                g <- dplyr::summarise(
                   g,
                   order=min(.data$order),
@@ -339,7 +367,8 @@ beidsServer <- function(
                   ),
                   Gene_name=paste(
                      setdiff(.data$Gene_name, NA), collapse=" / "
-                  )
+                  ),
+                  .groups = "drop"
                )
                g <- dplyr::arrange(g, .data$order)
                g <- dplyr::select(
@@ -587,19 +616,24 @@ beidsServer <- function(
             toShow <- dplyr::select(toShow, -"Organism")
          }
          toShow <- DT::datatable(
-            toShow,
+            dplyr::rename(
+               toShow, dplyr::all_of(stats::setNames("Match", matchColname))
+            ),
             rownames=FALSE,
             escape=FALSE,
             class = ifelse(compact, "display compact", "display"),
             selection=list(
                mode=ifelse(multiple, "multiple",  "single"),
+               selected = if(selectFirst) 1 else NULL,
                target="row"
             ),
+            extensions = 'Scroller',
             options=list(
                dom="t",
-               paging=FALSE,
+               paging=TRUE,
                scrollResize=TRUE,
                scrollY=tableHeight,
+               scroller = TRUE,
                scrollCollapse=TRUE
             )
          )
@@ -634,40 +668,62 @@ beidsServer <- function(
             return(NULL)
          }else{
             if(toGene){
-               ge <- unique(g$Gene_entity[sel])
-               toRet <- unique(m[
-                  which(m$Gene_entity %in% ge),
-                  c(
-                     "GeneID", "preferred_gene", "Gene_source", "organism",
-                     "Gene_entity"
+               if(groupBySymbol){
+                  ge <- dplyr::distinct(
+                     g[sel, c("Gene_entity", "Gene_symbol")]
                   )
-               ])
+                  toRet <- dplyr::inner_join(
+                     m[,c(
+                        "GeneID", "preferred_gene", "Gene_source", "organism",
+                        "Gene_entity", "Gene_symbol"
+                     )],
+                     ge,
+                     by = c("Gene_entity", "Gene_symbol")
+                  )
+               }else{
+                  ge <- unique(g$Gene_entity[sel])
+                  toRet <- unique(m[
+                     which(m$Gene_entity %in% ge),
+                     c(
+                        "GeneID", "preferred_gene", "Gene_source", "organism",
+                        "Gene_entity", "Gene_symbol"
+                     )
+                  ])
+               }
                colnames(toRet) <- c(
-                  "beid", "preferred", "source", "organism", "entity"
+                  "beid", "preferred", "source", "organism", "entity", "symbol"
                )
                if(nrow(toRet)>0){
                   toRet$be <- "Gene"
-                  toRet <- dplyr::left_join(
-                     toRet,
-                     g[,c("Gene_entity", "match")],
-                     by=c("entity"="Gene_entity")
-                  )
-                  toRet <- toRet[
-                     ,
-                     c(
-                        "beid", "preferred", "be", "source", "organism",
-                        "entity", "match"
+                  if(groupBySymbol){
+                     toRet <- dplyr::left_join(
+                        toRet,
+                        g[,c("Gene_entity", "Gene_symbol", "match")],
+                        by=c(
+                           "entity" = "Gene_entity",
+                           "symbol" = "Gene_symbol"
+                        )
                      )
-                  ]
+                  }else{
+                     toRet <- dplyr::left_join(
+                        toRet,
+                        g[,c("Gene_entity", "match")],
+                        by=c("entity"="Gene_entity")
+                     )
+                  }
+                  toRet <-  dplyr::distinct(toRet[, c(
+                     "beid", "preferred", "be", "source", "organism",
+                     "entity", "symbol", "match"
+                  )])
                }
             }else{
-               toRet <- m[
+               toRet <-  dplyr::distinct(m[
                   sel,
                   c(
                      "beid",  "preferred", "be", "source", "organism",
                      "entity", "match"
                   )
-               ]
+               ])
             }
             return(toRet)
          }
