@@ -4,9 +4,16 @@
 #'
 loadLuceneIndexes <- function(){
     pkgname <- utils::packageName()
+    nmv <- bedEnv$graph$version[1]
+    if(nmv == "3"){
+       mfile <- "BED-lucene-v3.cql"
+    }
+    if(nmv == "5"){
+       mfile <- "BED-lucene-v5.cql"
+    }
     ## Indexes
     cqlFile <- system.file(
-        "Documentation", "BED-Model", "BED-lucene.cql",
+        "Documentation", "BED-Model", mfile,
         package=pkgname
     )
     queries <- neo2R::readCql(cqlFile)
